﻿using System;
using System.Drawing;
using System.Windows.Forms;

namespace EsempioState
{
    public partial class Form1 : Form
    {
        private IParallelogramma _parallelogramma;
        private IServicesProvider _servicesProvider;

        public Form1()
        {
            InitializeComponent();
            SetServicesProvider("Step1");
        }

        private void _creaRettangoloButton_Click(object sender, EventArgs e)
        {
            _parallelogramma = _servicesProvider.CreaRettangolo(200, 100);
            _panel.Refresh();
        }

        private void _creaQuadratoButton_Click(object sender, EventArgs e)
        {
            _parallelogramma = _servicesProvider.CreaQuadrato(200);
            _panel.Refresh();
        }

        private void _ridimensionaButton_Click(object sender, EventArgs e)
        {
            if (_parallelogramma != null)
                _servicesProvider.Ridimensiona(_parallelogramma, _panel);
        }

        private void _panel_Paint(object sender, PaintEventArgs e)
        {
            if (_parallelogramma != null)
            {
                StringFormat stringFormat = new StringFormat();
                stringFormat.Alignment = StringAlignment.Center;
                stringFormat.LineAlignment = StringAlignment.Center;
                e.Graphics.DrawRectangle(new Pen(_parallelogramma.Colore, 3), 100, 100, (float) _parallelogramma.Larghezza, (float) _parallelogramma.Altezza);
                e.Graphics.DrawString(_parallelogramma.Nome, new Font("Arial", 16), new SolidBrush(_parallelogramma.Colore),
                    new RectangleF(100, 100, (float) _parallelogramma.Larghezza, (float) _parallelogramma.Altezza), stringFormat);
            }
        }

        private void _stepRadioButton_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton radioButton = (RadioButton) sender;
            SetServicesProvider(radioButton.Text);
        }

        private void SetServicesProvider(string stepName)
        {
            switch (stepName)
            {
                case "Step1":
                    _servicesProvider = new Step1.ServicesProvider();
                    break;
                case "Step2":
                    _servicesProvider = new Step2.ServicesProvider();
                    break;
                case "Step3":
                    _servicesProvider = new Step3.ServicesProvider();
                    break;
                default:
                    throw new ArgumentException("stepName");
            }
            _parallelogramma = null;
            _panel.Refresh();
        }
    }
}
